==> parcel-bundler-vue-1.6.3.tgz: package/lib/transforms/babel.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _map = require('babel-runtime/core-js/map');

var _map2 = _interopRequireDefault(_map);

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var babelTransform = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(asset) {
    var config, babel, res;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return getConfig(asset);

          case 2:
            config = _context.sent;

            if (config) {
              _context.next = 5;
              break;
            }

            return _context.abrupt('return');

          case 5:
            _context.next = 7;
            return asset.parseIfNeeded();

          case 7:
            if (!config.internal) {
              _context.next = 11;
              break;
            }

            _context.t0 = require('babel-core');
            _context.next = 14;
            break;

          case 11:
            _context.next = 13;
            return localRequire('babel-core', asset.name);

          case 13:
            _context.t0 = _context.sent;

          case 14:
            babel = _context.t0;

            if (!(parseInt(babel.version, 10) !== 6)) {
              _context.next = 17;
              break;
            }

            throw new Error('Unsupported babel version: ' + babel.version);

          case 17:
            res = babel.transformFromAst(asset.ast, asset.contents, config);

            if (!res.ignored) {
              asset.ast = res.ast;
              asset.isAstDirty = true;
            }

          case 19:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function babelTransform(_x) {
    return _ref.apply(this, arguments);
  };
}();

var getConfig = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(asset) {
    var config, internal;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return getBabelConfig(asset);

          case 2:
            config = _context2.sent;

            if (config) {
              config.code = false;
              config.filename = asset.name;
              config.babelrc = false;

              // Hide the internal property from babel
              internal = config.internal;

              delete config.internal;
              Object.defineProperty(config, 'internal', {
                value: internal
              });
            }

            return _context2.abrupt('return', config);

          case 5:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function getConfig(_x2) {
    return _ref2.apply(this, arguments);
  };
}();

var getBabelConfig = function () {
  var _ref3 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3(asset) {
    var babelrc, envConfig, jsxConfig, hasReact;
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            if (!asset.isES6Module) {
              _context3.next = 2;
              break;
            }

            return _context3.abrupt('return', {
              internal: true,
              plugins: [require('babel-plugin-transform-es2015-modules-commonjs')]
            });

          case 2:
            if (!asset.babelConfig) {
              _context3.next = 4;
              break;
            }

            return _context3.abrupt('return', asset.babelConfig);

          case 4:
            _context3.next = 6;
            return getBabelRc(asset);

          case 6:
            babelrc = _context3.sent;
            _context3.next = 9;
            return getEnvConfig(asset, !!babelrc);

          case 9:
            envConfig = _context3.sent;
            jsxConfig = getJSXConfig(asset, !!babelrc);

            // Merge the babel-preset-env config and the babelrc if needed

            if (!(babelrc && !shouldIgnoreBabelrc(asset.name, babelrc))) {
              _context3.next = 16;
              break;
            }

            if (envConfig) {
              // Filter out presets that are already applied by babel-preset-env
              if (Array.isArray(babelrc.presets)) {
                babelrc.presets = babelrc.presets.filter(function (preset) {
                  return !ENV_PRESETS[getPluginName(preset)];
                });
              }

              // Filter out plugins that are already applied by babel-preset-env
              if (Array.isArray(babelrc.plugins)) {
                babelrc.plugins = babelrc.plugins.filter(function (plugin) {
                  return !ENV_PLUGINS[getPluginName(plugin)];
                });
              }

              // Add plugins generated by babel-preset-env to get to the app's target engines.
              mergeConfigs(babelrc, envConfig);
            }

            // Add JSX config if it isn't already specified in the babelrc
            hasReact = hasPlugin(babelrc.presets, 'react') || hasPlugin(babelrc.plugins, 'transform-react-jsx');


            if (!hasReact) {
              mergeConfigs(babelrc, jsxConfig);
            }

            return _context3.abrupt('return', babelrc);

          case 16:
            if (!(envConfig && (envConfig.plugins.length > 0 || jsxConfig))) {
              _context3.next = 19;
              break;
            }

            mergeConfigs(envConfig, jsxConfig);
            return _context3.abrupt('return', envConfig);

          case 19:
            if (!jsxConfig) {
              _context3.next = 21;
              break;
            }

            return _context3.abrupt('return', jsxConfig);

          case 21:
            return _context3.abrupt('return', null);

          case 22:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));

  return function getBabelConfig(_x3) {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * Finds a .babelrc for an asset. By default, .babelrc files inside node_modules are not used.
 * However, there are some exceptions:
 *   - if `browserify.transforms` includes "babelify" in package.json (for legacy module compat)
 */
var getBabelRc = function () {
  var _ref4 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee4(asset) {
    var browserify, babelify;
    return _regenerator2.default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            // Support legacy browserify packages
            browserify = asset.package && asset.package.browserify;

            if (!(browserify && Array.isArray(browserify.transform))) {
              _context4.next = 13;
              break;
            }

            // Look for babelify in the browserify transform list
            babelify = browserify.transform.find(function (t) {
              return (Array.isArray(t) ? t[0] : t) === 'babelify';
            });

            // If specified as an array, override the config with the one specified

            if (!(Array.isArray(babelify) && babelify[1])) {
              _context4.next = 5;
              break;
            }

            return _context4.abrupt('return', babelify[1]);

          case 5:
            if (!babelify) {
              _context4.next = 11;
              break;
            }

            _context4.next = 8;
            return findBabelRc(asset);

          case 8:
            _context4.t0 = _context4.sent;
            _context4.next = 12;
            break;

          case 11:
            _context4.t0 = null;

          case 12:
            return _context4.abrupt('return', _context4.t0);

          case 13:
            if (asset.name.includes(NODE_MODULES)) {
              _context4.next = 17;
              break;
            }

            _context4.next = 16;
            return findBabelRc(asset);

          case 16:
            return _context4.abrupt('return', _context4.sent);

          case 17:
            return _context4.abrupt('return', null);

          case 18:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, this);
  }));

  return function getBabelRc(_x4) {
    return _ref4.apply(this, arguments);
  };
}();

var findBabelRc = function () {
  var _ref5 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee5(asset) {
    return _regenerator2.default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            if (!(asset.package && asset.package.babel)) {
              _context5.next = 2;
              break;
            }

            return _context5.abrupt('return', asset.package.babel);

          case 2:
            _context5.next = 4;
            return asset.getConfig(['.babelrc', '.babelrc.js']);

          case 4:
            return _context5.abrupt('return', _context5.sent);

          case 5:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, this);
  }));

  return function findBabelRc(_x5) {
    return _ref5.apply(this, arguments);
  };
}();

/**
 * Generates a babel-preset-env config for an asset.
 * This is done by finding the source module's target engines, and the app's
 * target engines, and doing a diff to include only the necessary plugins.
 */
var getEnvConfig = function () {
  var _ref6 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee6(asset, isSourceModule) {
    var targetEngines, targetEnv, sourceEngines, sourceEnv, sourcePlugins;
    return _regenerator2.default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.next = 2;
            return getTargetEngines(asset, true);

          case 2:
            targetEngines = _context6.sent;
            _context6.next = 5;
            return getEnvPlugins(targetEngines);

          case 5:
            targetEnv = _context6.sent;

            if (targetEnv) {
              _context6.next = 8;
              break;
            }

            return _context6.abrupt('return', null);

          case 8:
            if (!(asset.name.includes(NODE_MODULES) && !isSourceModule)) {
              _context6.next = 20;
              break;
            }

            _context6.next = 11;
            return getTargetEngines(asset, false);

          case 11:
            sourceEngines = _context6.sent;
            _context6.next = 14;
            return getEnvPlugins(sourceEngines);

          case 14:
            _context6.t0 = _context6.sent;

            if (_context6.t0) {
              _context6.next = 17;
              break;
            }

            _context6.t0 = targetEnv;

          case 17:
            sourceEnv = _context6.t0;


            // Do a diff of the returned plugins. We only need to process the remaining plugins to get to the app target.
            sourcePlugins = new _set2.default(sourceEnv.map(function (p) {
              return p[0];
            }));

            targetEnv = targetEnv.filter(function (plugin) {
              return !sourcePlugins.has(plugin[0]);
            });

          case 20:
            return _context6.abrupt('return', { plugins: targetEnv, internal: true });

          case 21:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, this);
  }));

  return function getEnvConfig(_x6, _x7) {
    return _ref6.apply(this, arguments);
  };
}();

var getEnvPlugins = function () {
  var _ref7 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee7(targets) {
    var key, plugins;
    return _regenerator2.default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            if (targets) {
              _context7.next = 2;
              break;
            }

            return _context7.abrupt('return', null);

          case 2:
            key = (0, _stringify2.default)(targets);

            if (!envCache.has(key)) {
              _context7.next = 5;
              break;
            }

            return _context7.abrupt('return', envCache.get(key));

          case 5:
            plugins = presetEnv.default({}, { targets: targets, modules: false }).plugins;

            envCache.set(key, plugins);
            return _context7.abrupt('return', plugins);

          case 8:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, this);
  }));

  return function getEnvPlugins(_x8) {
    return _ref7.apply(this, arguments);
  };
}();

/**
 * Generates a babel config for JSX. Attempts to detect react or react-like libraries
 * and changes the pragma accordingly.
 */


function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var presetEnv = require('babel-preset-env');
var getTargetEngines = require('../utils/getTargetEngines');
var localRequire = require('../utils/localRequire');
var path = require('path');

var _require = require('babel-core'),
    babelUtils = _require.util;

var NODE_MODULES = path.sep + 'node_modules' + path.sep;
var ENV_PLUGINS = require('babel-preset-env/data/plugins');
var ENV_PRESETS = {
  es2015: true,
  es2016: true,
  es2017: true,
  latest: true,
  env: true
};

var JSX_EXTENSIONS = {
  '.jsx': true,
  '.tsx': true
};

var JSX_PRAGMA = {
  react: 'React.createElement',
  preact: 'h',
  nervjs: 'Nerv.createElement',
  hyperapp: 'h'
};

module.exports = babelTransform;

babelTransform.getConfig = getConfig;

function mergeConfigs(a, b) {
  if (b) {
    a.presets = (a.presets || []).concat(b.presets || []);
    a.plugins = (a.plugins || []).concat(b.plugins || []);
  }

  return a;
}

function hasPlugin(arr, plugin) {
  return Array.isArray(arr) && arr.some(function (p) {
    return getPluginName(p) === plugin;
  });
}

function getPluginName(p) {
  return Array.isArray(p) ? p[0] : p;
}

function shouldIgnoreBabelrc(filename, babelrc) {
  // Determine if we should ignore this babelrc file. We do this here instead of
  // letting babel-core handle it because this config might be merged with our
  // autogenerated one later which shouldn't be ignored.
  var ignore = babelUtils.arrayify(babelrc.ignore, babelUtils.regexify);
  var only = babelrc.only && babelUtils.arrayify(babelrc.only, babelUtils.regexify);
  return babelUtils.shouldIgnore(filename, ignore, only);
}

var envCache = new _map2.default();

function getJSXConfig(asset, isSourceModule) {
  // Don't enable JSX in node_modules
  if (asset.name.includes(NODE_MODULES) && !isSourceModule) {
    return null;
  }

  // Find a dependency that we can map to a JSX pragma
  var pragma = null;
  for (var dep in JSX_PRAGMA) {
    var pkg = asset.package;
    if (pkg && (pkg.dependencies && pkg.dependencies[dep] || pkg.devDependencies && pkg.devDependencies[dep])) {
      pragma = JSX_PRAGMA[dep];
      break;
    }
  }

  if (pragma || JSX_EXTENSIONS[path.extname(asset.name)]) {
    return {
      plugins: [[require('babel-plugin-transform-react-jsx'), { pragma: pragma }]],
      internal: true
    };
  }
}

==> parcel-bundler-vue-2.0.0.tgz: package/lib/transforms/babel.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var shouldTransform = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(asset) {
    var babelrc;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (!asset.isES6Module) {
              _context2.next = 2;
              break;
            }

            return _context2.abrupt('return', true);

          case 2:
            if (!asset.ast) {
              _context2.next = 4;
              break;
            }

            return _context2.abrupt('return', !!asset.babelConfig);

          case 4:
            if (!(asset.package && asset.package.babel)) {
              _context2.next = 6;
              break;
            }

            return _context2.abrupt('return', true);

          case 6:
            _context2.next = 8;
            return asset.getConfig(['.babelrc', '.babelrc.js']);

          case 8:
            babelrc = _context2.sent;
            return _context2.abrupt('return', !!babelrc);

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function shouldTransform(_x2) {
    return _ref2.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var babel = require('babel-core');

module.exports = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(asset) {
    var config, res;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return shouldTransform(asset);

          case 2:
            if (_context.sent) {
              _context.next = 4;
              break;
            }

            return _context.abrupt('return');

          case 4:
            _context.next = 6;
            return asset.parseIfNeeded();

          case 6:
            config = {
              code: false,
              filename: asset.name
            };


            if (asset.isES6Module) {
              config.babelrc = false;
              config.plugins = [require('babel-plugin-transform-es2015-modules-commonjs')];
            }

            res = babel.transformFromAst(asset.ast, asset.contents, config);

            if (!res.ignored) {
              asset.ast = res.ast;
              asset.isAstDirty = true;
            }

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function (_x) {
    return _ref.apply(this, arguments);
  };
}();
